# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["SuppressionCreateParams"]


class SuppressionCreateParams(TypedDict, total=False):
    address: Required[str]
    """Email address to suppress"""

    reason: Optional[str]
    """Reason for suppression (accepts null)"""
